@@ -33,7 +33,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 use warnings;
 use Carp;
@@ -140,7 +140,7 @@ our %field_conf = (
     type => 'ARRAY',
     process => sub {
       my $val = shift;
-      if ($val =~ /^"(.+?[^\\])"\s*(.*)/) {
+      if ($val =~ /^"(.*?[^\\])"\s*(.*)/) {
         my $synonym = $1;
         my @dbxrefs = ();
         my $rest = $2;
